@@ -3,32 +3,31 @@
 import csv
 from urlparse import urlparse
 
-from ipaddr import IPv4Address, AddressValueError
-
-from twisted.web.client import GzipDecoder
+from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.internet.endpoints import TCP4ClientEndpoint
 from twisted.names import client
-
-from twisted.internet import defer
 from twisted.python import usage
+from twisted.web.client import GzipDecoder
 
 from ooni import geoip
-from ooni.utils import log
-
 from ooni.backend_client import WebConnectivityClient
-
-from ooni.common.http_utils import extractTitle
-from ooni.utils.net import COMMON_SERVER_HEADERS
-from ooni.templates import httpt, dnst
-from ooni.errors import failureToString
-
-from ooni.common.tcp_utils import TCPConnectFactory
 from ooni.common.http_utils import REQUEST_HEADERS
+from ooni.common.http_utils import extractTitle
+from ooni.common.ip_utils import is_public_ipv4_address
+from ooni.common.tcp_utils import TCPConnectFactory
+from ooni.errors import failureToString
+from ooni.templates import httpt, dnst
+from ooni.utils import log
+from ooni.utils.net import COMMON_SERVER_HEADERS
+
 
 class InvalidControlResponse(Exception):
     pass
 
+class AbsentHostname(Exception):
+    pass
+
 class UsageOptions(usage.Options):
     optParameters = [
         ['url', 'u', None, 'Specify a single URL to test'],
@@ -39,15 +38,6 @@ class UsageOptions(usage.Options):
     ]
 
 
-def is_public_ipv4_address(address):
-    try:
-        ip_address = IPv4Address(address)
-        return not any(
-            [ip_address.is_private, ip_address.is_loopback]
-        )
-    except AddressValueError:
-        return None
-
 class WebConnectivityTest(httpt.HTTPTest, dnst.DNSTest):
     """
     Web connectivity
@@ -76,6 +66,13 @@ class WebConnectivityTest(httpt.HTTPTest, dnst.DNSTest):
     requiresRoot = False
     requiresTor = False
     followRedirects = True
+    ignorePrivateRedirects = True
+
+    # These are the options to be shown on the GUI
+    simpleOptions = [
+        {"name": "url", "type": "text"},
+        {"name": "file", "type": "file/url"}
+    ]
 
     # Factor used to determine HTTP blockpage detection
     # the factor 0.7 comes from http://www3.cs.stonybrook.edu/~phillipa/papers/JLFG14.pdf
@@ -169,7 +166,7 @@ class WebConnectivityTest(httpt.HTTPTest, dnst.DNSTest):
 
         self.hostname = urlparse(self.input).netloc
         if not self.hostname:
-            raise Exception("Invalid input")
+            raise AbsentHostname('No hostname', self.input)
 
         self.control = {
             'tcp_connect': {},
@@ -344,10 +341,10 @@ class WebConnectivityTest(httpt.HTTPTest, dnst.DNSTest):
         if len(control_addrs.intersection(experiment_addrs)) > 0:
             return True
 
-        experiment_asns = set(map(lambda x: geoip.IPToLocation(x)['asn'],
-                              experiment_addrs))
-        control_asns = set(map(lambda x: geoip.IPToLocation(x)['asn'],
-                           control_addrs))
+        experiment_asns = set(map(lambda x: geoip.ip_to_location(x)['asn'],
+                                  experiment_addrs))
+        control_asns = set(map(lambda x: geoip.ip_to_location(x)['asn'],
+                               control_addrs))
 
         # Remove the instance of AS0 when we fail to find the ASN
         control_asns.discard('AS0')
