@@ -11,7 +11,7 @@ from twisted.python import usage
 
 from ooni.utils import log, net, randomStr
 from ooni.templates import httpt
-from ooni.utils.trueheaders import TrueHeaders
+from ooni.common.txextra import TrueHeaders
 
 
 def random_capitalization(string):
@@ -32,10 +32,10 @@ def random_capitalization(string):
 class UsageOptions(usage.Options):
     optParameters = [
         ['backend', 'b', None,
-         'URL of the backend to use for sending the requests'],
+         'URL of the backend to use for sending the requests.'],
         ['headers', 'h', None,
          'Specify a yaml formatted file from which to read '
-         'the request headers to send']
+         'the request headers to send.']
         ]
 
 
